﻿<?xml version="1.0" encoding="utf-8"?>
<xsl:stylesheet
  version="2.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  xmlns:my="myFunctions"
  xmlns:dcif="http://www.isocat.org/ns/dcif"   
>
<!-- 
<purpose> generate lists for Terms (CMDI-Elements, CMDI-components, Datcats)
 based on the Components-list (provided by CompReg).
		strategy:  regard CMD_Component, CMd_Element, ConceptLink</purpose>
<params>
<param name="isocat_file">the DCIF-Metadata-Profile</param>
</params>
<history>
	<change on="2010-07-10" type="created" by="vr">from complist2stats.xsl</change>	
</history>
-->
<xsl:include href="cmd_commons.xsl"/>
    
<xsl:param name="isocat_file" select="'../DCR/isocat_profile_5_dcif.xml'" />

<xsl:param name="title" select="'Terms'" />

<xsl:variable name="isocat" select="document($isocat_file)" />

<xsl:variable name="concepts_nolang" 
	select="//@ConceptLink[not(starts-with(.,'http://cdb.iso.org/lg/'))]" />


<xsl:variable name="term_matrix" >
		
		<xsl:for-each select="//CMD_Element" >
					<xsl:variable name="comp_path" >
							<xsl:for-each select="ancestor::CMD_Component" >
								<xsl:value-of select="@name" />/</xsl:for-each>
					</xsl:variable>
			<Term  elem="{@name}" datcat="{@ConceptLink}" profile="{ancestor::profileDescription[1]/name}" 
							parent="{ancestor::CMD_Component[1]/@name}"  comppath="{$comp_path}" >
								<xsl:copy-of select="." />
			</Term>
		</xsl:for-each>
	
</xsl:variable>
			

<xsl:template name="continue-root">
		<xsl:call-template name="list-terms" />
</xsl:template>			

<xsl:template name="summary-overall">
		<table>
		<tbody>
			<tr><td>profileDescription</td><td align="right"><xsl:value-of select="count(//profileDescription)"/></td></tr>			
			<tr><td>componentDescription</td><td align="right"><xsl:value-of select="count(//componentDescription)"/></td></tr>			
			<tr><td>CMD_ComponentSpec</td><td align="right"><xsl:value-of select="count(//CMD_ComponentSpec)"/></td></tr>
			<tr><td>profiles</td><td align="right"><xsl:value-of select="count(//CMD_ComponentSpec[@isProfile='true'])"/></td></tr>
			<tr><td>CMD_Component</td><td align="right"><xsl:value-of select="count(//CMD_Component)"/></td></tr>			
			<tr><td>distinct CMD_Component</td><td align="right"><xsl:value-of select="count(distinct-values(//CMD_Component/@name))"/></td></tr>			
			<tr><td>CMD_Element</td><td align="right"><xsl:value-of select="count(//CMD_Element)"/></td></tr>						
			<tr><td>distinct CMD_Element</td><td align="right"><xsl:value-of select="count(distinct-values(//CMD_Element/@name))"/></td></tr>						
			<tr><td>CMD_Elements without ConceptLink</td><td align="right"><xsl:value-of select="count(distinct-values(//CMD_Element[@ConceptLink='' or not(@ConceptLink)]/@name))"/></td></tr>						
			<tr><td>conceptlinks</td><td align="right"><xsl:value-of select="count(//@ConceptLink)"/></td></tr>						
			<tr><td>conceptlinks (without lang-codes ISO639)</td><td align="right"><xsl:value-of select="count($concepts_nolang)"/></td></tr>						
			<tr><td>distinct conceptlinks (without lang-codes)</td><td align="right"><xsl:value-of select="count(distinct-values($concepts_nolang))"/></td></tr>						
			<tr><td>distinct CMD_Elem-conceptlinks</td><td align="right"><xsl:value-of select="count(distinct-values($concepts_nolang[parent::CMD_Element]))"/></td></tr>						
			<tr><td>datcats in isocat-profile:Metadata#5</td><td align="right"><xsl:value-of select="count($isocat//dcif:dataCategory)"/></td></tr>						
			
			<tr><td>elem matrix</td><td align="right"><xsl:value-of select="count($term_matrix/Term)"/></td></tr>						
			<tr><td>distinct profile-elem</td><td align="right"><xsl:value-of select="count(distinct-values($term_matrix/Term/concat(@profile,@elem)))"/></td></tr>
			<tr><td>distinct profile-datcat</td><td align="right"><xsl:value-of select="count(distinct-values($term_matrix/Term/concat(@profile,@datcat)))"/></td></tr>
			<tr><td>distinct parent-elem</td><td align="right"><xsl:value-of select="count(distinct-values($term_matrix/Term/concat(@parent,@elem)))"/></td></tr>
			<tr><td>distinct profile-parent-elem</td><td align="right"><xsl:value-of select="count(distinct-values($term_matrix/Term/concat(@profile,@parent,@elem)))"/></td></tr>
			
		</tbody>
</table>
	
</xsl:template>			


<xsl:template name="summary-profiles">
	
	<table>
		<caption>Profiles |<xsl:value-of select="count(//profileDescription)" />|</caption>
		<thead><tr><th>name</th><th>|elem|</th><th>|distinct elems|</th><th>|distinct @ConceptLinks|</th></tr></thead>
		<tbody>		
				<xsl:for-each select="//profileDescription" >
					<xsl:sort select="name" order="ascending"/>					
						<tr><td><xsl:value-of select="name"/></td>									
							<td align="right"><xsl:value-of select="count(.//CMD_Element)"/></td>
							<td align="right"><xsl:value-of select="count(distinct-values(.//CMD_Element/@name))"/></td>
							<td align="right"><xsl:value-of select="count(distinct-values(.//CMD_Element/@ConceptLink))"/></td>
			
						</tr>
					
				</xsl:for-each>
		</tbody>
	</table>

</xsl:template>
	
<xsl:template name="list-terms">
	
	<div id="term-list" >
		<span class="box_heading" >Elements</span> <span class="note">|<xsl:value-of select="count($term_matrix/Term)" />/<xsl:value-of select="count(distinct-values($term_matrix/Term/@elem))" />|</span>
		
			<ul>
				<xsl:for-each-group select="$term_matrix/Term" group-by="lower-case(@elem)">
					<xsl:sort select="lower-case(@elem)" order="ascending"/>					
						<li><span class="term_detail_caller" ><a href="{@elem}" ><xsl:value-of select="@elem"/></a></span>
									<span class="note" >
										|<xsl:value-of select="count(distinct-values(current-group()/@datcat))"/>/
											<xsl:value-of select="count(distinct-values(current-group()/@profile))"/>/
											<xsl:value-of select="count(current-group())"/>|
											<!-- <xsl:value-of select="count(distinct-values(current-group()//node()[not(name()='CMD_Element')]/@ConceptLink))"/> -->
									</span>
								<div class="term_detail" >
									<div class="box_heading"><xsl:value-of select="@elem"/></div>
										<ul>
											<xsl:for-each-group select="current-group()" group-by="@datcat">
												<li><xsl:value-of select="my:shortURL(@datcat)"/>
													<ul>
														<xsl:for-each-group select="current-group()" group-by="@profile" >
															<li><xsl:value-of select="@profile" />
																	<ul>
																		<xsl:for-each select="current-group()/@comppath" >
																				<li><xsl:value-of select="." /></li>
																		</xsl:for-each>
																	</ul>
															</li>
														</xsl:for-each-group>
													</ul>
												</li>						
											</xsl:for-each-group>
										</ul>
								</div>							
						
						</li>
				</xsl:for-each-group>
			</ul>	
	</div>
</xsl:template>
	
<xsl:template name="list-datcats">
	
	<table>
		<caption>DatCats |<xsl:value-of select="count(distinct-values($term_matrix/Term/@datcat))" />| <span class="note">* Click on numbers to see detail </span></caption>
				<thead><tr><th rowspan="2">id</th><th rowspan="2">name</th>
					<th colspan="3" >count </th><th rowspan="2">elems</th></tr>
					<tr><th>profile*</th><th >all*</th><th>elems</th> </tr>		</thead>
		<tbody>		
				<xsl:for-each-group select="$term_matrix/Term" group-by="@datcat">
					<xsl:sort select="lower-case(@datcat)" order="ascending"/>					
						<tr><td valign="top"><xsl:value-of select="my:shortURL(@datcat)"/></td>
						<td valign="top"><xsl:value-of select="my:rewriteURL(@datcat)"/></td>
						<td valign="top" align="right">
							<span class="term_detail_caller" ><xsl:value-of select="count(distinct-values(current-group()/@profile))"/></span>
							<div class="term_detail" >
									<div class="box_heading"><xsl:value-of select="my:rewriteURL(@datcat)"/></div>
									<ul>
										<xsl:for-each select="distinct-values(current-group()/@profile)" >
											<li><xsl:value-of select="." /></li>
										</xsl:for-each>
									</ul>
								</div>							
						</td>
						<td valign="top" align="right">
							<span class="term_detail_caller" ><xsl:value-of select="count(current-group())"/></span>
							<div class="term_detail" >
									<div class="box_heading"><xsl:value-of select="my:rewriteURL(@datcat)"/></div>
									<ul>
										<xsl:for-each-group select="current-group()" group-by="@profile" >
											<li><xsl:value-of select="@profile" />
													<ul>
														<xsl:for-each select="current-group()/@comppath" >
																<li><xsl:value-of select="." /></li>
														</xsl:for-each>
													</ul>
											</li>
										</xsl:for-each-group>
									</ul>
								</div>							
						</td>
						<td valign="top" align="right"><xsl:value-of select="count(distinct-values(current-group()/@elem))"/></td>						
							
						<td width="40%">						
								<xsl:for-each select="distinct-values(current-group()/@elem)">
									<xsl:sort select="." />
									<xsl:value-of select="."/>,
								</xsl:for-each>
						</td>												
						</tr>					
				</xsl:for-each-group>
		</tbody>
	</table>
	</xsl:template>

	<!--
	obsolete 
<xsl:function name="m:shorturl" >
	<xsl:param name="url" />
	<xsl:value-of select="replace($url, 'http://www.isocat.org/datcat/','isocat:')" />	
</xsl:function>	

<xsl:function name="m:resolve" >
	<xsl:param name="url" />	
	<xsl:message>1:<xsl:value-of select="$url" /></xsl:message>
	<xsl:variable name="field" select="'name'" />
	<xsl:variable name="datcat"  select="$isocat//dcif:dataCategory[@pid=$url]" />	
	<xsl:value-of select="$datcat/@name" />
	<xsl:message><xsl:value-of select="$datcat/@name" /></xsl:message>
</xsl:function>	

<xsl:function name="m:resolve" >
	<xsl:param name="url" />
	<xsl:param name="field" />
	<xsl:message>2:<xsl:value-of select="$url" /></xsl:message>
	<xsl:variable name="datcat"  select="$isocat//dcif:dataCategory[@pid=$url]" />	
	<xsl:value-of select="$datcat/@*[name()=$field]" />
	
</xsl:function>	
-->

<xsl:template name="obsolete">

 <!--
 <style type="text/css">
 		.term_detail { text-align: left; border: 1px solid #666699; background-color: #ccccff; position:absolute; }
 		.term_detail ul { padding-left: 16px; }
 		.hilight { background-color: #ccccff;}
 		.box_heading {font-weight:bold;}
 </style>

			<script type="text/javascript">			
				$(function(){
					
					$('.term_detail').hide();
					
					$('.term_detail_caller').click(function() {
									$(this).parent().find('.term_detail').toggle();
									$(this).parents('tr').toggleClass('hilight');
								});
				});
			</script>
 -->
</xsl:template>			


</xsl:stylesheet>